@@ -8,38 +8,41 @@ void init_dcfmtsym(py::module &m) {
   // icu::DecimalFormatSymbols
   py::class_<DecimalFormatSymbols, UObject> dfs(m, "DecimalFormatSymbols");
 
-  py::enum_<DecimalFormatSymbols::ENumberFormatSymbol>(dfs, "ENumberFormatSymbol", py::arithmetic())
-      .value("DECIMAL_SEPARATOR_SYMBOL", DecimalFormatSymbols::kDecimalSeparatorSymbol)
-      .value("GROUPING_SEPARATOR_SYMBOL", DecimalFormatSymbols::kGroupingSeparatorSymbol)
-      .value("PATTERN_SEPARATOR_SYMBOL", DecimalFormatSymbols::kPatternSeparatorSymbol)
-      .value("PERCENT_SYMBOL", DecimalFormatSymbols::kPercentSymbol)
-      .value("ZERO_DIGIT_SYMBOL", DecimalFormatSymbols::kZeroDigitSymbol)
-      .value("DIGIT_SYMBOL", DecimalFormatSymbols::kDigitSymbol)
-      .value("MINUS_SIGN_SYMBOL", DecimalFormatSymbols::kMinusSignSymbol)
-      .value("PLUS_SIGN_SYMBOL", DecimalFormatSymbols::kPlusSignSymbol)
-      .value("CURRENCY_SYMBOL", DecimalFormatSymbols::kCurrencySymbol)
-      .value("INTL_CURRENCY_SYMBOL", DecimalFormatSymbols::kIntlCurrencySymbol)
-      .value("MONETARY_SEPARATOR_SYMBOL", DecimalFormatSymbols::kMonetarySeparatorSymbol)
-      .value("EXPONENTIAL_SYMBOL", DecimalFormatSymbols::kExponentialSymbol)
-      .value("PER_MILL_SYMBOL", DecimalFormatSymbols::kPerMillSymbol)
-      .value("PAD_ESCAPE_SYMBOL", DecimalFormatSymbols::kPadEscapeSymbol)
-      .value("INFINITY_SYMBOL", DecimalFormatSymbols::kInfinitySymbol)
-      .value("NAN_SYMBOL", DecimalFormatSymbols::kNaNSymbol)
-      .value("SIGNIFICANT_DIGIT_SYMBOL", DecimalFormatSymbols::kSignificantDigitSymbol)
-      .value("MONETARY_GROUPING_SEPARATOR_SYMBOL", DecimalFormatSymbols::kMonetaryGroupingSeparatorSymbol)
-      .value("ONE_DIGIT_SYMBOL", DecimalFormatSymbols::kOneDigitSymbol)
-      .value("TWO_DIGIT_SYMBOL", DecimalFormatSymbols::kTwoDigitSymbol)
-      .value("THREE_DIGIT_SYMBOL", DecimalFormatSymbols::kThreeDigitSymbol)
-      .value("FOUR_DIGIT_SYMBOL", DecimalFormatSymbols::kFourDigitSymbol)
-      .value("FIVE_DIGIT_SYMBOL", DecimalFormatSymbols::kFiveDigitSymbol)
-      .value("SIX_DIGIT_SYMBOL", DecimalFormatSymbols::kSixDigitSymbol)
-      .value("SEVEN_DIGIT_SYMBOL", DecimalFormatSymbols::kSevenDigitSymbol)
-      .value("EIGHT_DIGIT_SYMBOL", DecimalFormatSymbols::kEightDigitSymbol)
-      .value("NINE_DIGIT_SYMBOL", DecimalFormatSymbols::kNineDigitSymbol)
+  py::enum_<DecimalFormatSymbols::ENumberFormatSymbol>(dfs, "ENumberFormatSymbol", py::arithmetic(),
+                                                       "Constants for specifying a number format symbol.")
+      .value("DECIMAL_SEPARATOR_SYMBOL", DecimalFormatSymbols::kDecimalSeparatorSymbol, "The decimal separator.")
+      .value("GROUPING_SEPARATOR_SYMBOL", DecimalFormatSymbols::kGroupingSeparatorSymbol, "The grouping separator.")
+      .value("PATTERN_SEPARATOR_SYMBOL", DecimalFormatSymbols::kPatternSeparatorSymbol, "The pattern separator.")
+      .value("PERCENT_SYMBOL", DecimalFormatSymbols::kPercentSymbol, "The percent sign.")
+      .value("ZERO_DIGIT_SYMBOL", DecimalFormatSymbols::kZeroDigitSymbol, "Zero.")
+      .value("DIGIT_SYMBOL", DecimalFormatSymbols::kDigitSymbol, "Character representing a digit in the pattern.")
+      .value("MINUS_SIGN_SYMBOL", DecimalFormatSymbols::kMinusSignSymbol, "The minus sign.")
+      .value("PLUS_SIGN_SYMBOL", DecimalFormatSymbols::kPlusSignSymbol, "The plus sign.")
+      .value("CURRENCY_SYMBOL", DecimalFormatSymbols::kCurrencySymbol, "The currency symbol.")
+      .value("INTL_CURRENCY_SYMBOL", DecimalFormatSymbols::kIntlCurrencySymbol, "The international currency symbol.")
+      .value("MONETARY_SEPARATOR_SYMBOL", DecimalFormatSymbols::kMonetarySeparatorSymbol, "The monetary separator.")
+      .value("EXPONENTIAL_SYMBOL", DecimalFormatSymbols::kExponentialSymbol, "The exponential symbol.")
+      .value("PER_MILL_SYMBOL", DecimalFormatSymbols::kPerMillSymbol, "Per mill symbol - replaces kPermillSymbol.")
+      .value("PAD_ESCAPE_SYMBOL", DecimalFormatSymbols::kPadEscapeSymbol, "Escape padding character.")
+      .value("INFINITY_SYMBOL", DecimalFormatSymbols::kInfinitySymbol, "Infinity symbol.")
+      .value("NAN_SYMBOL", DecimalFormatSymbols::kNaNSymbol, "Nan symbol.")
+      .value("SIGNIFICANT_DIGIT_SYMBOL", DecimalFormatSymbols::kSignificantDigitSymbol, "Significant digit symbol.")
+      .value("MONETARY_GROUPING_SEPARATOR_SYMBOL", DecimalFormatSymbols::kMonetaryGroupingSeparatorSymbol,
+             "The monetary grouping separator.")
+      .value("ONE_DIGIT_SYMBOL", DecimalFormatSymbols::kOneDigitSymbol, "One.")
+      .value("TWO_DIGIT_SYMBOL", DecimalFormatSymbols::kTwoDigitSymbol, "Two.")
+      .value("THREE_DIGIT_SYMBOL", DecimalFormatSymbols::kThreeDigitSymbol, "Three.")
+      .value("FOUR_DIGIT_SYMBOL", DecimalFormatSymbols::kFourDigitSymbol, "Four.")
+      .value("FIVE_DIGIT_SYMBOL", DecimalFormatSymbols::kFiveDigitSymbol, "Five.")
+      .value("SIX_DIGIT_SYMBOL", DecimalFormatSymbols::kSixDigitSymbol, "Six.")
+      .value("SEVEN_DIGIT_SYMBOL", DecimalFormatSymbols::kSevenDigitSymbol, "Seven.")
+      .value("EIGHT_DIGIT_SYMBOL", DecimalFormatSymbols::kEightDigitSymbol, "Eight.")
+      .value("NINE_DIGIT_SYMBOL", DecimalFormatSymbols::kNineDigitSymbol, "Nine.")
 #if (U_ICU_VERSION_MAJOR_NUM >= 54)
-      .value("EXPONENT_MULTIPLICATION_SYMBOL", DecimalFormatSymbols::kExponentMultiplicationSymbol)
+      .value("EXPONENT_MULTIPLICATION_SYMBOL", DecimalFormatSymbols::kExponentMultiplicationSymbol,
+             "Multiplication sign.")
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 54)
-      .value("FORMAT_SYMBOL_COUNT", DecimalFormatSymbols::kFormatSymbolCount)
+      .value("FORMAT_SYMBOL_COUNT", DecimalFormatSymbols::kFormatSymbolCount, "Count symbol constants.")
       .export_values();
 
   dfs.def(
