@@ -24,7 +24,7 @@ void init_gregocal(py::module &m) {
       .def("__repr__", [](const Calendar &self) {
         std::stringstream ss;
         UErrorCode error_code = U_ZERO_ERROR;
-        auto fmt = SimpleDateFormat(u"yyyy-MM-dd'T'HH:mm:ssXXXXX", error_code);
+        auto fmt = SimpleDateFormat(u"yyyy-MM-dd'T'HH:mm:ss.SSSXXX", error_code);
         fmt.setCalendar(self);
         UnicodeString dest;
         fmt.format(self.getTime(error_code), dest);
@@ -372,7 +372,8 @@ void init_gregocal(py::module &m) {
   // icu::GregorianCalendar
   py::class_<GregorianCalendar, Calendar> gc(m, "GregorianCalendar");
 
-  py::enum_<GregorianCalendar::EEras>(gc, "EEras", py::arithmetic())
+  py::enum_<GregorianCalendar::EEras>(gc, "EEras", py::arithmetic(),
+                                      "Useful constants for *GregorianCalendar* and *TimeZone*.")
       .value("BC", GregorianCalendar::EEras::BC)
       .value("AD", GregorianCalendar::EEras::AD)
       .export_values();
@@ -464,7 +465,7 @@ void init_gregocal(py::module &m) {
       .def("__repr__", [](const Calendar &self) {
         std::stringstream ss;
         UErrorCode error_code = U_ZERO_ERROR;
-        auto fmt = SimpleDateFormat(u"yyyy-MM-dd'T'HH:mm:ssXXXXX", error_code);
+        auto fmt = SimpleDateFormat(u"yyyy-MM-dd'T'HH:mm:ss.SSSXXX", error_code);
         fmt.setCalendar(self);
         UnicodeString dest;
         fmt.format(self.getTime(error_code), dest);
