@@ -13,6 +13,8 @@ using namespace icu;
 
 void init_alphaindex(py::module &m);
 void init_appendable(py::module &m);
+void init_caniter(py::module &m);
+void init_casemap(py::module &m);
 void init_char16ptr(py::module &m);
 void init_coleitr(py::module &m);
 void init_compactdecimalformat(py::module &m);
@@ -27,17 +29,22 @@ void init_dtitvfmt(py::module &m);
 void init_dtitvinf(py::module &m);
 void init_dtptngen(py::module &m);
 void init_dtrule(py::module &m);
+void init_edits(py::module &m);
 void init_errorcode(py::module &m);
 void init_fieldpos(py::module &m);
+void init_filteredbrk(py::module &m);
 void init_fmtable(py::module &m, py::class_<Formattable, UObject> &fmt);
 void init_format(py::module &m);
 void init_formattedvalue(py::module &m);
 void init_fpositer(py::module &m);
+void init_gender(py::module &m);
 void init_gregocal(py::module &m);
+void init_icudataver(py::module &m);
 void init_idna(py::module &m);
 void init_listformatter(py::module &m);
 void init_localebuilder(py::module &m);
 void init_localematcher(py::module &m);
+void init_locdspnm(py::module &m);
 void init_locid(py::module &m, py::class_<Locale, UObject> &loc);
 void init_measfmt(py::module &m);
 void init_measunit(py::module &m);
@@ -57,13 +64,16 @@ void init_plurrule(py::module &m, py::class_<PluralRules, UObject> &pr);
 void init_rbbi(py::module &m);
 void init_rbnf(py::module &m);
 void init_regex(py::module &m);
+void init_region(py::module &m);
 void init_reldatefmt(py::module &m);
 void init_resbund(py::module &m);
 void init_schriter(py::module &m);
+void init_scientificnumberformatter(py::module &m);
 void init_selfmt(py::module &m);
 void init_smpdtfmt(py::module &m);
 void init_sortkey(py::module &m);
 void init_strenum(py::module &m);
+void init_stringoptions(py::module &m);
 void init_stsearch(py::module &m);
 void init_tblcoll(py::module &m);
 void init_timezone(py::module &m);
@@ -90,9 +100,12 @@ void init_udatpg(py::module &m);
 void init_udisplaycontext(py::module &m);
 void init_uenum(py::module &m);
 void init_uformattedvalue(py::module &m);
+void init_ugender(py::module &m);
 void init_uidna(py::module &m);
+void init_uldnames(py::module &m);
 void init_ulistformatter(py::module &m);
 void init_uloc(py::module &m);
+void init_ulocdata(py::module &m);
 void init_uniset(py::module &m);
 void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class_<UnicodeString, Replaceable> &us);
 void init_unorm2(py::module &m);
@@ -101,6 +114,7 @@ void init_unumberformatter(py::module &m);
 void init_unumberrangeformatter(py::module &m);
 void init_upluralrules(py::module &m);
 void init_uregex(py::module &m);
+void init_uregion(py::module &m);
 void init_ureldatefmt(py::module &m);
 void init_ures(py::module &m);
 void init_uscript(py::module &m);
@@ -230,22 +244,32 @@ PYBIND11_MODULE(MODULE_NAME, m) {
   init_decimfmt(m, decfmt);             // icu::DecimalFormat
   init_compactdecimalformat(m);         // icu::CompactDecimalFormat
   init_plurfmt(m);                      // icu::PluralFormat
+  init_scientificnumberformatter(m);    // icu::ScientificNumberFormatter
 
   init_schriter(m); // icu::StringCharacterIterator
   init_coleitr(m);  // icu::CollationElementIterator
 
+  init_caniter(m);       // icu::CanonicalIterator
   init_dtptngen(m);      // icu::DateTimePatternGenerator
+  init_gender(m);        // icu::GenderInfo
   init_idna(m);          // icu::IDNA
   init_listformatter(m); // icu::ListFormatter
   init_localebuilder(m); // icu::LocaleBuilder
   init_localematcher(m); // icu::LocaleMatcher
+  init_locdspnm(m);      // icu::LocaleDisplayNames
   init_locid(m, loc);    // icu::Locale
   init_rbbi(m);          // icu::RuleBasedBreakIterator
   init_regex(m);         // icu::RegexPattern, icu::RegexMatcher
+  init_region(m);        // icu::Region
   init_reldatefmt(m);    // icu::RelativeDateTimeFormatter
   init_resbund(m);       // icu::ResourceBundle
   init_sortkey(m);       // icu::CollationKey
 
+  init_filteredbrk(m); // icu::FilteredBreakIteratorBuilder
+
+  init_edits(m);   // icu::Edits
+  init_casemap(m); // icu::CaseMap
+
   init_uniset(m);      // icu::UnicodeSet
   init_usetiter(m);    // icu::UnicodeSetIterator
   init_normalizer2(m); // icu::Normalizer2, icu::FilteredNormalizer2
@@ -257,6 +281,8 @@ PYBIND11_MODULE(MODULE_NAME, m) {
 
   init_unistr(m, rep, us); // icu::UnicodeString
 
+  init_icudataver(m);
+  init_stringoptions(m);
   init_ubidi(m);
   init_ubiditransform(m);
   init_ubrk(m);
@@ -274,15 +300,19 @@ PYBIND11_MODULE(MODULE_NAME, m) {
   init_udisplaycontext(m);
   init_uenum(m);
   init_uformattedvalue(m);
+  init_ugender(m);
   init_uidna(m);
+  init_uldnames(m);
   init_ulistformatter(m);
   init_uloc(m);
+  init_ulocdata(m);
   init_unorm2(m);
   init_unum(m);
   init_unumberformatter(m);
   init_unumberrangeformatter(m);
   init_upluralrules(m);
   init_uregex(m);
+  init_uregion(m);
   init_ureldatefmt(m);
   init_ures(m);
   init_uscript(m);
