@@ -6,8 +6,17 @@ using namespace icu;
 
 void init_numfmt(py::module & /*m*/, py::class_<NumberFormat, Format> &nf) {
   // icu::NumberFormat
-  py::enum_<NumberFormat::EAlignmentFields>(nf, "EAlignmentFields", py::arithmetic())
-      .value("INTEGER_FIELD", NumberFormat::kIntegerField)
+  py::enum_<NumberFormat::EAlignmentFields>(
+      nf, "EAlignmentFields", py::arithmetic(),
+      "Alignment Field constants used to construct a *FieldPosition* object.\n\n"
+      "Signifies that the position of the integer part or fraction part of a formatted number should be returned.\n\n"
+      "Note: as of ICU 4.4, the values in this enum have been extended to support identification of all number format "
+      "fields, not just those pertaining to alignment.\n\n"
+      "These constants are provided for backwards compatibility only. Please use the C style constants defined in the "
+      "header file unum.h.")
+      .value("INTEGER_FIELD", NumberFormat::kIntegerField,
+             "These constants are provided for backwards compatibility only.\n\n  "
+             "Please use the constants defined in the header file unum.h.")
       .value("FRACTION_FIELD", NumberFormat::kFractionField)
       .value("DECIMAL_SEPARATOR_FIELD", NumberFormat::kDecimalSeparatorField)
       .value("EXPONENT_SYMBOL_FIELD", NumberFormat::kExponentSymbolField)
@@ -24,15 +33,23 @@ void init_numfmt(py::module & /*m*/, py::class_<NumberFormat, Format> &nf) {
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 64)
       .export_values();
 
-  py::enum_<NumberFormat::ERoundingMode>(nf, "ERoundingMode", py::arithmetic())
-      .value("ROUND_CEILING", NumberFormat::kRoundCeiling)
-      .value("ROUND_FLOOR", NumberFormat::kRoundFloor)
-      .value("ROUND_DOWN", NumberFormat::kRoundDown)
-      .value("ROUND_UP", NumberFormat::kRoundUp)
-      .value("ROUND_HALF_EVEN", NumberFormat::kRoundHalfEven)
-      .value("ROUND_HALF_DOWN", NumberFormat::kRoundHalfDown)
-      .value("ROUND_HALF_UP", NumberFormat::kRoundHalfUp)
-      .value("ROUND_UNNECESSARY", NumberFormat::kRoundUnnecessary)
+  py::enum_<NumberFormat::ERoundingMode>(
+      nf, "ERoundingMode", py::arithmetic(),
+      "Rounding mode.\n\n"
+      "For more detail on rounding modes, see: "
+      "https://unicode-org.github.io/icu/userguide/format_parse/numbers/rounding-modes")
+      .value("ROUND_CEILING", NumberFormat::kRoundCeiling, "Round towards positive infinity.")
+      .value("ROUND_FLOOR", NumberFormat::kRoundFloor, "Round towards negative infinity.")
+      .value("ROUND_DOWN", NumberFormat::kRoundDown, "Round towards zero.")
+      .value("ROUND_UP", NumberFormat::kRoundUp, "Round away from zero.")
+      .value("ROUND_HALF_EVEN", NumberFormat::kRoundHalfEven,
+             "Round towards the nearest integer, or towards the nearest even integer if equidistant.")
+      .value("ROUND_HALF_DOWN", NumberFormat::kRoundHalfDown,
+             "Round towards the nearest integer, or towards zero if equidistant.")
+      .value("ROUND_HALF_UP", NumberFormat::kRoundHalfUp,
+             "Round towards the nearest integer, or away from zero if equidistant.")
+      .value("ROUND_UNNECESSARY", NumberFormat::kRoundUnnecessary,
+             "Return *U_FORMAT_INEXACT_ERROR* if number does not format exactly.")
       .export_values();
 
   nf.def(
