@@ -9,7 +9,7 @@ using namespace icu;
 
 void init_reldatefmt(py::module &m) {
 #if (U_ICU_VERSION_MAJOR_NUM >= 53)
-  py::enum_<UDateAbsoluteUnit>(m, "UDateAbsoluteUnit", py::arithmetic())
+  py::enum_<UDateAbsoluteUnit>(m, "UDateAbsoluteUnit", py::arithmetic(), "Represents an absolute unit.")
       .value("UDAT_ABSOLUTE_SUNDAY", UDAT_ABSOLUTE_SUNDAY, "Sunday.")
       .value("UDAT_ABSOLUTE_MONDAY", UDAT_ABSOLUTE_MONDAY, "Monday.")
       .value("UDAT_ABSOLUTE_TUESDAY", UDAT_ABSOLUTE_TUESDAY, "Tuesday.")
@@ -33,24 +33,31 @@ void init_reldatefmt(py::module &m) {
 
 #ifndef U_HIDE_DEPRECATED_API
       .value("UDAT_ABSOLUTE_UNIT_COUNT", UDAT_ABSOLUTE_UNIT_COUNT,
-             "Deprecated: ICU 58 The numeric value may change over time, see ICU ticket #12420.")
+             "**Deprecated:** ICU 58 The numeric value may change over time, see ICU ticket #12420.")
 #endif // U_HIDE_DEPRECATED_API
       .export_values();
 
-  py::enum_<UDateDirection>(m, "UDateDirection", py::arithmetic())
-      .value("UDAT_DIRECTION_LAST_2", UDAT_DIRECTION_LAST_2, "Two before. Not fully supported in every locale.")
+  py::enum_<UDateDirection>(m, "UDateDirection", py::arithmetic(),
+                            "Represents a direction for an absolute unit e.g., \"Next Tuesday\" or \"Last Tuesday\".")
+      .value("UDAT_DIRECTION_LAST_2", UDAT_DIRECTION_LAST_2,
+             "Two before.\n\n  "
+             "Not fully supported in every locale.")
       .value("UDAT_DIRECTION_LAST", UDAT_DIRECTION_LAST, "Last.")
       .value("UDAT_DIRECTION_THIS", UDAT_DIRECTION_THIS, "This.")
       .value("UDAT_DIRECTION_NEXT", UDAT_DIRECTION_NEXT, "Next.")
-      .value("UDAT_DIRECTION_NEXT_2", UDAT_DIRECTION_NEXT_2, "Two after. Not fully supported in every locale.")
+      .value("UDAT_DIRECTION_NEXT_2", UDAT_DIRECTION_NEXT_2,
+             "Two after.\n\n  "
+             "Not fully supported in every locale.")
       .value("UDAT_DIRECTION_PLAIN", UDAT_DIRECTION_PLAIN, "Plain, which means the absence of a qualifier.")
 #ifndef U_HIDE_DEPRECATED_API
       .value("UDAT_DIRECTION_COUNT", UDAT_DIRECTION_COUNT,
-             "Deprecated: ICU 58 The numeric value may change over time, see ICU ticket #12420.")
+             "**Deprecated:** ICU 58 The numeric value may change over time, see ICU ticket #12420.")
 #endif // U_HIDE_DEPRECATED_API
       .export_values();
 
-  py::enum_<UDateRelativeUnit>(m, "UDateRelativeUnit", py::arithmetic())
+  py::enum_<UDateRelativeUnit>(m, "UDateRelativeUnit", py::arithmetic(),
+                               "Represents the unit for formatting a relative date.\n\n"
+                               "e.g., \"in 5 days\" or \"in 3 months\"")
       .value("UDAT_RELATIVE_SECONDS", UDAT_RELATIVE_SECONDS, "Seconds.")
       .value("UDAT_RELATIVE_MINUTES", UDAT_RELATIVE_MINUTES, "Minutes.")
       .value("UDAT_RELATIVE_HOURS", UDAT_RELATIVE_HOURS, "Hours.")
@@ -60,7 +67,7 @@ void init_reldatefmt(py::module &m) {
       .value("UDAT_RELATIVE_YEARS", UDAT_RELATIVE_YEARS, "Years.")
 #ifndef U_HIDE_DEPRECATED_API
       .value("UDAT_RELATIVE_UNIT_COUNT", UDAT_RELATIVE_UNIT_COUNT,
-             "Deprecated: ICU 58 The numeric value may change over time, see ICU ticket #12420.")
+             "**Deprecated:** ICU 58 The numeric value may change over time, see ICU ticket #12420.")
 #endif // U_HIDE_DEPRECATED_API
       .export_values();
 
@@ -146,7 +153,7 @@ void init_reldatefmt(py::module &m) {
           py::init([](const Locale &locale, NumberFormat *nf_to_adopt) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = std::make_unique<RelativeDateTimeFormatter>(
-                locale, nf_to_adopt ? nf_to_adopt->clone() : nullptr, error_code);
+                locale, reinterpret_cast<NumberFormat *>(nf_to_adopt ? nf_to_adopt->clone() : nullptr), error_code);
             if (U_FAILURE(error_code)) {
               throw ICUError(error_code);
             }
@@ -158,7 +165,7 @@ void init_reldatefmt(py::module &m) {
           py::init([](const char *locale, NumberFormat *nf_to_adopt) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = std::make_unique<RelativeDateTimeFormatter>(
-                locale, nf_to_adopt ? nf_to_adopt->clone() : nullptr, error_code);
+                locale, reinterpret_cast<NumberFormat *>(nf_to_adopt ? nf_to_adopt->clone() : nullptr), error_code);
             if (U_FAILURE(error_code)) {
               throw ICUError(error_code);
             }
@@ -172,7 +179,8 @@ void init_reldatefmt(py::module &m) {
                       UDisplayContext capitalization_context) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = std::make_unique<RelativeDateTimeFormatter>(
-                locale, nf_to_adopt ? nf_to_adopt->clone() : nullptr, style, capitalization_context, error_code);
+                locale, reinterpret_cast<NumberFormat *>(nf_to_adopt ? nf_to_adopt->clone() : nullptr), style,
+                capitalization_context, error_code);
             if (U_FAILURE(error_code)) {
               throw ICUError(error_code);
             }
@@ -185,7 +193,8 @@ void init_reldatefmt(py::module &m) {
                       UDisplayContext capitalization_context) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = std::make_unique<RelativeDateTimeFormatter>(
-                locale, nf_to_adopt ? nf_to_adopt->clone() : nullptr, style, capitalization_context, error_code);
+                locale, reinterpret_cast<NumberFormat *>(nf_to_adopt ? nf_to_adopt->clone() : nullptr), style,
+                capitalization_context, error_code);
             if (U_FAILURE(error_code)) {
               throw ICUError(error_code);
             }
