@@ -7,12 +7,14 @@
 #include <pybind11/stl.h>
 
 void init_ucnv(py::module &m) {
-  py::enum_<UConverterPlatform>(m, "UConverterPlatform", py::arithmetic())
+  py::enum_<UConverterPlatform>(m, "UConverterPlatform", py::arithmetic(),
+                                "Enum for specifying which platform a converter ID refers to.\n\n"
+                                "The use of platform/CCSID is not recommended. See *ucnv_open_ccsid()*.")
       .value("UCNV_UNKNOWN", UCNV_UNKNOWN)
       .value("UCNV_IBM", UCNV_IBM)
       .export_values();
 
-  py::enum_<UConverterType>(m, "UConverterType", py::arithmetic())
+  py::enum_<UConverterType>(m, "UConverterType", py::arithmetic(), "Enum for specifying basic types of converters.")
       .value("UCNV_UNSUPPORTED_CONVERTER", UCNV_UNSUPPORTED_CONVERTER)
       .value("UCNV_SBCS", UCNV_SBCS)
       .value("UCNV_DBCS", UCNV_DBCS)
@@ -52,11 +54,14 @@ void init_ucnv(py::module &m) {
       .value("UCNV_NUMBER_OF_SUPPORTED_CONVERTER_TYPES", UCNV_NUMBER_OF_SUPPORTED_CONVERTER_TYPES)
       .export_values();
 
-  py::enum_<UConverterUnicodeSet>(m, "UConverterUnicodeSet", py::arithmetic())
-      .value("UCNV_ROUNDTRIP_SET", UCNV_ROUNDTRIP_SET)
-      .value("UCNV_ROUNDTRIP_AND_FALLBACK_SET", UCNV_ROUNDTRIP_AND_FALLBACK_SET)
+  py::enum_<UConverterUnicodeSet>(m, "UConverterUnicodeSet", py::arithmetic(),
+                                  "Selectors for Unicode sets that can be returned by *ucnv_get_unicode_set()*.")
+      .value("UCNV_ROUNDTRIP_SET", UCNV_ROUNDTRIP_SET, "Select the set of roundtrippable Unicode code points.")
+      .value("UCNV_ROUNDTRIP_AND_FALLBACK_SET", UCNV_ROUNDTRIP_AND_FALLBACK_SET,
+             "Select the set of Unicode code points with roundtrip or fallback mappings.")
 #ifndef U_HIDE_DEPRECATED_API
-      .value("UCNV_SET_COUNT", UCNV_SET_COUNT)
+      .value("UCNV_SET_COUNT", UCNV_SET_COUNT,
+             "**Deprecated:** ICU 58 The numeric value may change over time, see ICU ticket #12420.")
 #endif // U_HIDE_DEPRECATED_API
       .export_values();
 
@@ -166,6 +171,26 @@ void init_ucnv(py::module &m) {
       py::arg("converter"), py::arg("display_locale"));
   m.def(
       "ucnv_get_from_u_call_back",
+      [](const _UConverterPtr &converter) {
+        PyErr_WarnEx(nullptr,
+                     "ucnv_get_from_u_call_back() is deprecated and will be removed in a future release. "
+                     "Use ucnv_get_from_ucall_back() instead.",
+                     1);
+        UConverterFromUCallback action;
+        const void *context;
+        ucnv_getFromUCallBack(converter, &action, &context);
+        if (action == _UConverterFromUCallbackPtr::callback) {
+          // Python callback function and callback data
+          auto result2 = reinterpret_cast<_ConstVoidPtr *>(const_cast<void *>(context));
+          auto result1 = _UConverterFromUCallbackPtr(result2->get_action());
+          return py::make_tuple(result1, result2);
+        }
+        // C callback function and callback data
+        return py::make_tuple(_UConverterFromUCallbackPtr(action), _ConstVoidPtr(context));
+      },
+      py::return_value_policy::reference, py::arg("converter"));
+  m.def(
+      "ucnv_get_from_ucall_back",
       [](const _UConverterPtr &converter) {
         UConverterFromUCallback action;
         const void *context;
@@ -239,6 +264,26 @@ void init_ucnv(py::module &m) {
       py::arg("converter"));
   m.def(
       "ucnv_get_to_u_call_back",
+      [](const _UConverterPtr &converter) {
+        PyErr_WarnEx(nullptr,
+                     "ucnv_get_to_u_call_back() is deprecated and will be removed in a future release. "
+                     "Use ucnv_get_to_ucall_back() instead.",
+                     1);
+        UConverterToUCallback action;
+        const void *context;
+        ucnv_getToUCallBack(converter, &action, &context);
+        if (action == _UConverterToUCallbackPtr::callback) {
+          // Python callback function and callback data
+          auto result2 = reinterpret_cast<_ConstVoidPtr *>(const_cast<void *>(context));
+          auto result1 = _UConverterToUCallbackPtr(result2->get_action());
+          return py::make_tuple(result1, result2);
+        }
+        // C callback function and callback data
+        return py::make_tuple(_UConverterToUCallbackPtr(action), _ConstVoidPtr(context));
+      },
+      py::return_value_policy::reference, py::arg("converter"));
+  m.def(
+      "ucnv_get_to_ucall_back",
       [](const _UConverterPtr &converter) {
         UConverterToUCallback action;
         const void *context;
@@ -344,6 +389,43 @@ void init_ucnv(py::module &m) {
       py::arg("cnv"), py::arg("uses_fallback"));
   m.def(
       "ucnv_set_from_u_call_back",
+      [](_UConverterPtr &converter, _UConverterFromUCallbackPtr &new_action, _ConstVoidPtr &new_context) {
+        PyErr_WarnEx(nullptr,
+                     "ucnv_set_from_u_call_back() is deprecated and will be removed in a future release. "
+                     "Use ucnv_set_from_ucall_back() instead.",
+                     1);
+        UConverterFromUCallback fp = new_action.get_if<UConverterFromUCallback>();
+        const void *cp = nullptr;
+        if (fp == nullptr) {
+          // New Python callback function and callback data
+          fp = new_action.callback;
+          new_context.set_action(new_action.get<py::function>());
+          cp = &new_context;
+        } else if (new_context.has_value()) {
+          // New C callback data
+          cp = new_context.to_c_str();
+        }
+
+        UConverterFromUCallback old_action;
+        const void *old_context;
+        UErrorCode error_code = U_ZERO_ERROR;
+        ucnv_setFromUCallBack(converter, fp, cp, &old_action, &old_context, &error_code);
+        if (U_FAILURE(error_code)) {
+          throw ICUError(error_code);
+        }
+        if (old_action == new_action.callback) {
+          // Old Python callback function and callback data
+          auto result2 = reinterpret_cast<_ConstVoidPtr *>(const_cast<void *>(old_context));
+          auto result1 = _UConverterFromUCallbackPtr(result2->get_action());
+          return py::make_tuple(result1, result2);
+        }
+        // Old C callback function and callback data
+        return py::make_tuple(_UConverterFromUCallbackPtr(old_action), _ConstVoidPtr(old_context));
+      },
+      py::return_value_policy::reference, py::keep_alive<2, 1>(), py::keep_alive<3, 1>(), py::arg("converter"),
+      py::arg("new_action"), py::arg("new_context"));
+  m.def(
+      "ucnv_set_from_ucall_back",
       [](_UConverterPtr &converter, _UConverterFromUCallbackPtr &new_action, _ConstVoidPtr &new_context) {
         UConverterFromUCallback fp = new_action.get_if<UConverterFromUCallback>();
         const void *cp = nullptr;
@@ -398,6 +480,43 @@ void init_ucnv(py::module &m) {
       py::arg("converter"), py::arg("s"), py::arg("length"));
   m.def(
       "ucnv_set_to_u_call_back",
+      [](_UConverterPtr &converter, _UConverterToUCallbackPtr &new_action, _ConstVoidPtr &new_context) {
+        PyErr_WarnEx(nullptr,
+                     "ucnv_set_to_u_call_back() is deprecated and will be removed in a future release. "
+                     "Use ucnv_set_to_ucall_back() instead.",
+                     1);
+        UConverterToUCallback fp = new_action.get_if<UConverterToUCallback>();
+        const void *cp = nullptr;
+        if (fp == nullptr) {
+          // New Python callback function and callback data
+          fp = new_action.callback;
+          new_context.set_action(new_action.get<py::function>());
+          cp = &new_context;
+        } else if (new_context.has_value()) {
+          // New C callback data
+          cp = new_context.to_c_str();
+        }
+
+        UConverterToUCallback old_action;
+        const void *old_context;
+        UErrorCode error_code = U_ZERO_ERROR;
+        ucnv_setToUCallBack(converter, fp, cp, &old_action, &old_context, &error_code);
+        if (U_FAILURE(error_code)) {
+          throw ICUError(error_code);
+        }
+        if (old_action == new_action.callback) {
+          // Old Python callback function and callback data
+          auto result2 = reinterpret_cast<_ConstVoidPtr *>(const_cast<void *>(old_context));
+          auto result1 = _UConverterToUCallbackPtr(result2->get_action());
+          return py::make_tuple(result1, result2);
+        }
+        // Old C callback function and callback data
+        return py::make_tuple(_UConverterToUCallbackPtr(old_action), _ConstVoidPtr(old_context));
+      },
+      py::return_value_policy::reference, py::keep_alive<2, 1>(), py::keep_alive<3, 1>(), py::arg("converter"),
+      py::arg("new_action"), py::arg("new_context"));
+  m.def(
+      "ucnv_set_to_ucall_back",
       [](_UConverterPtr &converter, _UConverterToUCallbackPtr &new_action, _ConstVoidPtr &new_context) {
         UConverterToUCallback fp = new_action.get_if<UConverterToUCallback>();
         const void *cp = nullptr;
