@@ -1,5 +1,5 @@
 import pytest
-from icupy import (
+from icupy.icu import (
     ErrorCode, ICUError, UErrorCode, U_ICU_VERSION_MAJOR_NUM,
     u_failure, u_get_version, u_success, u_version_from_string,
     u_version_to_string,
@@ -31,7 +31,7 @@ def test_icu_error():
     assert error_code == UErrorCode.U_ILLEGAL_ARGUMENT_ERROR
 
     if U_ICU_VERSION_MAJOR_NUM >= 63:
-        from icupy import Locale
+        from icupy.icu import Locale
 
         with pytest.raises(ICUError) as exc_info:
             _ = Locale.for_language_tag("x")
@@ -74,7 +74,7 @@ def test_icu_exception():
     assert error_code == UErrorCode.U_ILLEGAL_ARGUMENT_ERROR
 
     if U_ICU_VERSION_MAJOR_NUM >= 63:
-        from icupy import Locale
+        from icupy.icu import Locale
 
         with pytest.raises(ICUException) as exc_info:
             _ = Locale.for_language_tag("x")
@@ -91,15 +91,28 @@ def test_u_failure():
     assert u_failure(UErrorCode.U_ILLEGAL_ARGUMENT_ERROR)
 
 
+@pytest.mark.skipif(U_ICU_VERSION_MAJOR_NUM < 49, reason="ICU4C<49")
+def test_u_get_data_version():
+    from icupy.icu import u_get_data_version
+
+    # void u_getDataVersion(
+    #       UVersionInfo dataVersionFillin,
+    #       UErrorCode *status
+    # )
+    data_version = u_get_data_version()
+    assert isinstance(data_version, list)
+    assert len(data_version) == 4
+    assert all(isinstance(x, int) for x in data_version)
+    assert all(x >= 0 for x in data_version)
+
+
 def test_u_get_version():
     # void u_getVersion(UVersionInfo versionArray)
     version_array = u_get_version()
     assert isinstance(version_array, list)
     assert len(version_array) == 4
-    assert version_array[0] > 0
-    assert version_array[1] >= 0
-    assert version_array[2] >= 0
-    assert version_array[3] >= 0
+    assert all(isinstance(x, int) for x in version_array)
+    assert all(x >= 0 for x in version_array)
 
 
 def test_u_success():
