@@ -1,22 +1,21 @@
-import copy
-
 import pytest
-from icupy import U_ICU_VERSION_MAJOR_NUM
+from icupy.icu import U_ICU_VERSION_MAJOR_NUM
 
 if U_ICU_VERSION_MAJOR_NUM < 60:
     pytest.skip("ICU4C<60", allow_module_level=True)
 
-from icupy import (
+import copy
+
+from icupy.icu import (
     CurrencyUnit, DecimalFormatSymbols, ErrorCode, Format, Formattable,
     INT32_MAX, Locale, MeasureUnit, UCurrencyUsage, UErrorCode,
     UNumberDecimalSeparatorDisplay, UNumberFormatRoundingMode,
     UNumberSignDisplay, UNumberUnitWidth, UParseError, UnicodeString,
     UnicodeStringAppendable,
 )
-from icupy.number import (
-    CurrencyPrecision, FormattedNumber, FractionPrecision, IncrementPrecision,
-    IntegerWidth, LocalizedNumberFormatter, Notation, NumberFormatter,
-    Precision, ScientificNotation, UnlocalizedNumberFormatter,
+from icupy.icu.number import (
+    FormattedNumber, IntegerWidth, LocalizedNumberFormatter, Notation,
+    NumberFormatter, ScientificNotation, UnlocalizedNumberFormatter,
 )
 
 
@@ -48,7 +47,7 @@ def test_formatted_number_62():
 
 @pytest.mark.skipif(U_ICU_VERSION_MAJOR_NUM < 64, reason="ICU4C<64")
 def test_formatted_number_64():
-    from icupy import (
+    from icupy.icu import (
         ConstrainedFieldPosition, FormattedValue, UFieldCategory,
         UNumberFormatFields,
     )
@@ -195,13 +194,6 @@ def test_localized_number_formatter_60():
     result = fmt2.notation(Notation.compact_long())
     assert isinstance(result, LocalizedNumberFormatter)
 
-    # template<typename Derived>
-    # Derived icu::number::NumberFormatterSettings<Derived>::sign(
-    #       UNumberSignDisplay style
-    # )
-    result = fmt.sign(UNumberSignDisplay.UNUM_SIGN_AUTO)
-    assert isinstance(result, LocalizedNumberFormatter)
-
     # template<typename Derived>
     # Derived icu::number::NumberFormatterSettings<Derived>::symbols(
     #       const DecimalFormatSymbols &symbols
@@ -226,7 +218,7 @@ def test_localized_number_formatter_60():
 
 @pytest.mark.skipif(U_ICU_VERSION_MAJOR_NUM < 61, reason="ICU4C<61")
 def test_localized_number_formatter_61():
-    from icupy import UNumberGroupingStrategy
+    from icupy.icu import UNumberGroupingStrategy
 
     fmt = NumberFormatter.with_locale(Locale.get_us())
     assert isinstance(fmt, LocalizedNumberFormatter)
@@ -248,7 +240,7 @@ def test_localized_number_formatter_61():
 
 @pytest.mark.skipif(U_ICU_VERSION_MAJOR_NUM < 62, reason="ICU4C<62")
 def test_localized_number_formatter_62():
-    from icupy.number import Scale
+    from icupy.icu.number import Precision, Scale
 
     # [1]
     # icu::number::LocalizedNumberFormatter::LocalizedNumberFormatter()
@@ -288,6 +280,13 @@ def test_localized_number_formatter_62():
     result = fmt.scale(Scale.power_of_ten(2))
     assert isinstance(result, LocalizedNumberFormatter)
 
+    # template<typename Derived>
+    # Derived icu::number::NumberFormatterSettings<Derived>::sign(
+    #       UNumberSignDisplay style
+    # )
+    result = fmt.sign(UNumberSignDisplay.UNUM_SIGN_AUTO)
+    assert isinstance(result, LocalizedNumberFormatter)
+
     # template<typename Derived>
     # UnicodeString icu::number::NumberFormatterSettings<Derived>::toSkeleton(
     #       UErrorCode &status
@@ -334,10 +333,14 @@ def test_localized_number_formatter_68():
 
 @pytest.mark.skipif(U_ICU_VERSION_MAJOR_NUM < 68, reason="ICU4C<68")
 def test_no_unit():
-    from icupy import NoUnit
+    from icupy.icu import NoUnit
 
     fmt = NumberFormatter.with_locale(Locale.get_us())
 
+    unit = NoUnit.base()
+    assert isinstance(unit, MeasureUnit)
+    assert fmt.unit(unit).format_int(1).to_string() == "1"
+
     unit = NoUnit.percent()
     assert isinstance(unit, MeasureUnit)
     assert fmt.unit(unit).format_int(1).to_string() == "1%"
@@ -421,7 +424,12 @@ def test_notation():
         ScientificNotation)
 
 
-def test_precision_60():
+@pytest.mark.skipif(U_ICU_VERSION_MAJOR_NUM < 62, reason="ICU4C<62")
+def test_precision_60_62():
+    from icupy.icu.number import (
+        CurrencyPrecision, FractionPrecision, IncrementPrecision, Precision,
+    )
+
     # icu::number::Precision
     assert isinstance(Precision.currency(UCurrencyUsage.UCURR_USAGE_STANDARD),
                       CurrencyPrecision)
@@ -458,6 +466,8 @@ def test_precision_60():
 
 @pytest.mark.skipif(U_ICU_VERSION_MAJOR_NUM < 62, reason="ICU4C<62")
 def test_precision_62():
+    from icupy.icu.number import Precision
+
     # icu::number::Precision
     assert isinstance(Precision.fixed_significant_digits(3), Precision)
     assert isinstance(Precision.max_significant_digits(4), Precision)
@@ -467,7 +477,8 @@ def test_precision_62():
 
 @pytest.mark.skipif(U_ICU_VERSION_MAJOR_NUM < 69, reason="ICU4C<69")
 def test_precision_69():
-    from icupy import UNumberRoundingPriority, UNumberTrailingZeroDisplay
+    from icupy.icu import UNumberRoundingPriority, UNumberTrailingZeroDisplay
+    from icupy.icu.number import Precision
 
     # icu::number::Precision
     assert isinstance(
@@ -488,7 +499,7 @@ def test_precision_69():
 
 @pytest.mark.skipif(U_ICU_VERSION_MAJOR_NUM < 62, reason="ICU4C<62")
 def test_scale():
-    from icupy.number import Scale
+    from icupy.icu.number import Scale
 
     # icu::number::Scale
     assert isinstance(Scale.by_decimal("5.2"), Scale)
@@ -546,13 +557,6 @@ def test_unlocalized_number_formatter_60():
     result = fmt2.notation(Notation.compact_long())
     assert isinstance(result, UnlocalizedNumberFormatter)
 
-    # template<typename Derived>
-    # Derived icu::number::NumberFormatterSettings<Derived>::sign(
-    #       UNumberSignDisplay style
-    # )
-    result = fmt.sign(UNumberSignDisplay.UNUM_SIGN_AUTO)
-    assert isinstance(result, UnlocalizedNumberFormatter)
-
     # template<typename Derived>
     # Derived icu::number::NumberFormatterSettings<Derived>::symbols(
     #       const DecimalFormatSymbols &symbols
@@ -577,7 +581,7 @@ def test_unlocalized_number_formatter_60():
 
 @pytest.mark.skipif(U_ICU_VERSION_MAJOR_NUM < 61, reason="ICU4C<61")
 def test_unlocalized_number_formatter_61():
-    from icupy import UNumberGroupingStrategy
+    from icupy.icu import UNumberGroupingStrategy
 
     fmt = NumberFormatter.with_()
     assert isinstance(fmt, UnlocalizedNumberFormatter)
@@ -599,7 +603,7 @@ def test_unlocalized_number_formatter_61():
 
 @pytest.mark.skipif(U_ICU_VERSION_MAJOR_NUM < 62, reason="ICU4C<62")
 def test_unlocalized_number_formatter_62():
-    from icupy.number import Scale
+    from icupy.icu.number import Precision, Scale
 
     # [1]
     # icu::number::UnlocalizedNumberFormatter::UnlocalizedNumberFormatter()
@@ -626,6 +630,13 @@ def test_unlocalized_number_formatter_62():
     result = fmt.scale(Scale.power_of_ten(2))
     assert isinstance(result, UnlocalizedNumberFormatter)
 
+    # template<typename Derived>
+    # Derived icu::number::NumberFormatterSettings<Derived>::sign(
+    #       UNumberSignDisplay style
+    # )
+    result = fmt.sign(UNumberSignDisplay.UNUM_SIGN_AUTO)
+    assert isinstance(result, UnlocalizedNumberFormatter)
+
     # template<typename Derived>
     # UnicodeString icu::number::NumberFormatterSettings<Derived>::toSkeleton(
     #       UErrorCode &status
