@@ -1,5 +1,5 @@
 import pytest
-from icupy import (
+from icupy.icu import (
     ConstVoidPtr, ICUError, RegexMatcher, RegexPattern, UErrorCode,
     URegexFindProgressCallbackPtr, URegexMatchCallbackPtr, URegexpFlag,
     UTextVector, UnicodeString, UnicodeStringVector,
@@ -7,8 +7,7 @@ from icupy import (
     utext_open_const_unicode_string, utext_open_unicode_string,
     utext_open_utf8, utext_replace,
 )
-
-from . import gc
+from icupy.utils import gc
 
 
 def test_api():
