@@ -1,4 +1,4 @@
-from icupy import (
+from icupy.icu import (
     ConstVoidPtr,
     UBIDI_DEFAULT_LTR, UBIDI_DO_MIRRORING, UBIDI_INSERT_LRM_FOR_NUMERIC,
     UBIDI_LEVEL_OVERRIDE, UBIDI_MAP_NOWHERE,
@@ -21,8 +21,7 @@ from icupy import (
     ubidi_set_line, ubidi_set_para, ubidi_set_reordering_mode,
     ubidi_set_reordering_options, ubidi_write_reordered, ubidi_write_reverse,
 )
-
-from . import gc
+from icupy.utils import gc
 
 
 def test_api():
