@@ -1,13 +1,12 @@
 import copy
 
 import pytest
-from icupy import (
+from icupy.icu import (
     Appendable, ICUError, INT32_MAX, Locale, U_ICU_VERSION_MAJOR_NUM,
     UErrorCode, UnicodeString, UnicodeStringAppendable, UnicodeStringVector,
     US_INV, u_unescape, ucnv_close, ucnv_open,
 )
-
-from . import gc
+from icupy.utils import gc
 
 
 def test_append():
