@@ -1,5 +1,5 @@
 import pytest
-from icupy import (
+from icupy.icu import (
     ICUError, StringCharacterIterator, UErrorCode, UTextVector,
     U_SENTINEL, UnicodeString,
     utext_char32_at, utext_clone, utext_close, utext_copy, utext_current32,
@@ -12,8 +12,7 @@ from icupy import (
     utext_open_utf8, utext_previous32, utext_previous32_from, utext_replace,
     utext_set_native_index,
 )
-
-from . import gc
+from icupy.utils import gc
 
 
 def test_api():
